#ifndef _MOTORME_H
#define _MOTORME_H

/**********************************************************************
 *                 Copyright by Mekatronix 1998                       *
 * Title          motorme.h                                           *
 * Programmer     Keith L. Doty                                       *
 * Date           May 03, 1999                                        *
 * Version        1.1                                                 *
 * Description                                                        *
 *    This module controls the left and right wheel motors of the     *
 *    TALRIK robot. Functions perform motor initialization and motor  *
 *    speed control. Two PWM interrupt drivers for motor0 (PA5,OC3)   *
 *    (Left Wheel Motor) and motor1 (PA6, OC2) (Right Wheel Motor)    *
 *    control motor speed.                                            *
 *                                                                    *
 *    Driver motor0 uses OC3 and motor1 uses OC2 timers for the PWM.  *
 *                                                                    *
 * Version History:                                                   *
 *                                                                    *
 **********************************************************************/


/*************************** Includes *********************************/

#include <hc11.h>
#include <mil.h>

/************************ End of Includes *****************************/


/*************************** Constants ********************************/

#define motor0 TOC3_isr
#define motor1 TOC2_isr
#define PERIODM 65,500   /*Full period for a motor in clock cycles*/
#define PERIOD_1PC 655   /*A clock cycle is 0.5 microseconds	*/

#define LEFT_MOTOR 0
#define RIGHT_MOTOR 1


/************************ End of Constants ****************************/


/*************************** Prototypes *******************************/

#pragma interrupt_handler TOC2_isr, TOC3_isr;
   void init_motorme(void);
   void motor0(void);
   void motor1(void);
   void motorme(int, int);

/************************ End of Prototypes ***************************/


#endif
