/**********************************************************************
 * Title        servotme.h  (Servo Drivers for TJ PRO)                *
 * Programmer   Keith L. Doty			                      *
 * Date         May 07, 1999                                          *
 * Version      1                                                     *
 *                                                                    *
 * Description: Servo drivers.					      *
	servo 0 on PA3 
	servo 1 on PA4 
	servo 2 on PA5 "Left motor"
	servo 3 on PA6 "Right motor"
	servo 4 on PA7

	All pulse widths created in sequence, i.e., the five servos
	are phase shifted relative to one another by the pulse width 
	of the servo that preceeds it in the sequence.

	If any of the other OCx's are used, do not connect a servo to
        the corresponding PortA pin. For example, if OC2 drives a
        motor attached to PA6, the the OC2 signals overrides
        the servo commands on PA6 and drives the servo with the OC2
        signal. This could overheat and ruin a servo attached to PA6.

 * History:     Total revision					      *
 **********************************************************************/


/**************************** Includes **********************************/
#include <hc11.h>
#include <mil.h>
/************************************************************************/


/**************************** Constants *********************************/
#define HALFPERIOD 20000         /* 50Hz refresh for each servo */
#define NSERVO 5				/* Number of servos */

//Servo limits. PWnL is the lower limit for servo n
//		PWnU is the lower limit for servo n
// These limits can be individualized for each servo

#define PW0L 600
#define PW0U 4800
#define PW1L 600
#define PW1U 4800
#define PW2L 600
#define PW2U 4800
#define PW3L 600
#define PW3U 4800
#define PW4L 600
#define PW4U 4800

/*
  When srv_lim_default==1, servo(servo#,pulse_width) verifies that
  			PWnL <= pulse_width <= PWnU
  
  Changing the #defines for PWnL and PWnU and recompiling provides a
  compile time values for the servo limits.
*/

//Change SRV_LIMIT_DEFAULT to 0 to disable servo limit checking
#define SRV_LIMIT_DEFAULT 1 

/************************************************************************/


/*************************** Prototypes *********************************/
#pragma interrupt_handler TOC4_isr
void init_servome(void);

/*
   servo() Arguments:
   Servo# (0,1,2,3,4,5,6,7), Pulse Width(0 or 2000 to 4000)
*/
void servo(int, int); 
 
void servo_hand(void);
/************************************************************************/

/**************************** Globals *********************************/

 /*
  When srv_lim_default==1, servo(servo#,pulse_width) verifies that
      servo_limits[servo#][0]<= pulse_width fall <= servo_limits[servo#][1]

  You can dynamically change servo limits for the current execution by
  changing the appropriate contents of servo_limits[servo#][0] (lower) and
  servo_limits[servo#][1] (upper).
*/
 unsigned int servo_limits[NSERVO][2]=
 {
 	{PW0L,PW0U},
 	{PW1L,PW1U},
 	{PW2L,PW2U},
 	{PW3L,PW3U},
 	{PW4L,PW4U}
 };
 
//You can dynamically change srv_lim_default to disable limit checks
//in current execution. 
 char srv_lim_default= SRV_LIMIT_DEFAULT;
 
 
 /* servo_width[] is the on-time for each servo*/
 unsigned int previous_pwidth;
 unsigned int servo_width[NSERVO]; 
 unsigned char servo_signal_state, servomask[NSERVO];
 int period_end;

 
 
 
 
 
 

/**************************** End Globals *********************************/
 