	.module motorme2.c
	.dbfile motorme2.c
	.area text
;  IX -> 0,x
_init_motorme::
			sei

	.dbfile motorme2.c
	.dbfunc init_motorme
	.dbline 72
; /**********************************************************************
;  * 			MEKATRONIX Copyright 1998 		      *
;  * Title        motorme.c  (Motor Drivers for ME11)                *
;  * Programmer   Keith L. Doty                      *
;  * Date         May 09, 1999                                        *
;  * 				                                                     *
;  * Version      1  
;      Changed some names, set PACTL bits with one command, cleaned up.
;  *                                                                    *
;  * Description                                                        *
;  * Left motor is motor 1 (PA6) and right motor is motor 0 (PA5).      *
;  * For efficient use of output compares, OC5 is used to modulate pins *
;  * both PA5 and PA6. 		      *
;  **********************************************************************/
; 
; 
; /**************************** Includes **********************************/
; #include <hc11.h>
; #include <mil.h>
; /************************************************************************/
; 
; 
; /**************************** Constants *********************************/
; /*Full period for a motor in clock cycles. A clock cycle is 0.5 microseconds*/
; #define HALFPERIOD 32,750
; 
; /* One percent of full motor period in clock cycles*/
; #define PERIOD_1PC 655   
; 
; #define LEFT_MOTOR 1
; #define RIGHT_MOTOR 0
; 
; #define motortme_hand   TOC5_isr
; /************************************************************************/
; 
; 
; /*************************** Prototypes *********************************/
; #pragma interrupt_handler TOC5_isr
; void init_motorme(void);
; void motorme(int, int);
; void motorme_hand();
; /************************************************************************/
; 
; 
; /***************************** Globals **********************************/
; unsigned int duty_cycle[2];       /* duty_cycle[] is the on-time for each motor*/
; unsigned int current_duty_cycle;
; char signal_state, motormask[2];
; /************************************************************************/
; 
; 
; 
; void init_motorme(void)
; /************************************************************************
;  * Function: Initializes all necessary variables for the motors.        *
;  * Returns: None                                                        *
;  *                                                                      *
;  * Inputs                                                               *
;  *   Parameters: None                                                   *
;  *   Globals:    None                                                   *
;  *   Registers:  None                                                   *
;  * Outputs                                                              *
;  *   Parameters: None                                                   *
;  *   Globals:   duty_cycle[], signal_state, motormask[], current_duty_cycle       *
;  *   Registers: TOC5, TMSK1, TCTL1                               *
;  * Functions called: None                                               *
;  * Notes: None                                                          *
;  ************************************************************************/
; {
; 
;   INTR_OFF();
;   CLEAR_BIT(TCTL1,0x03);          /* Interrupt will not affect OC5 pin */
	ldy #0x1020
	bclr 0,y,#0x3
	.dbline 74
; 
;   duty_cycle[0] = duty_cycle[1] =  0;      /* Motors start turned off */
	ldd #0
	std _duty_cycle+2
	ldd #0
	std _duty_cycle
	.dbline 75
;   TOC5 = 0;                       
	ldd #0
	std 0x101e
	.dbline 76
;   signal_state = 0;
	clr _signal_state
	.dbline 77
;   current_duty_cycle = 0;
	ldd #0
	std _current_duty_cycle
	.dbline 78
;   motormask[0] = 0x20;		/* Drives PA5, right motor*/
	ldab #32
	stab _motormask
	.dbline 79
;   motormask[1] = 0x40;		/* Drives PA6, left motor*/
	ldab #64
	stab _motormask+1
	.dbline 82
; 
; 
;   SET_BIT(TMSK1,0x08);            /* Enable OC5 interrupt */
	ldy #0x1022
	bset 0,y,#8
			cli

	.dbline 84
;   INTR_ON();
; }/*end init_motorme*/
L2:
	rts
;  IX -> 0,x
; per_cent_duty_cycle -> 8,x
;          index -> 4,x
_motorme::
	pshb
	psha
	pshx
	pshx
	tsx
	stx 0,x
	.dbfunc motorme
	.dbline 108
; 
; 
; void motorme(int index, int per_cent_duty_cycle)
; /************************************************************************
;  * Function description:						*
;  *   Sets duty cycle and direction of motor specified by index.	    	*
;  *				                                        *
;  * Returns:                                                           	*
;  *                                                                    	*
;  * Inputs                                                             	*
;  *   Parameters: index: 0 = left motor, 1 = right motor               	*
;  *		     -100 <= per_cent_duty_cycle<= 100%		        *
;  *   Globals:    None                                                 	*
;  *   Registers:  None                                                 	*
;  * Outputs                                                            	*
;  *   Parameters: None                                                 	*
;  *   Globals:    duty_cycle[index]					*
;         0 <= duty_cycle[index]<= PERIOD (Typically, PERIOD = 65,500)  	*
;  *   Registers:  None                                                 	*
;  * Functions called: None                                             	*
;  * Notes: Checks for proper input bounds. 			 	*
;  ************************************************************************/
; {
;   if (per_cent_duty_cycle < 0)
	ldd 8,x
	bge L6
	.dbline 110
;      {
;         per_cent_duty_cycle = -per_cent_duty_cycle; /* Make positive */
	ldd 8,x
	nega
	negb
	sbca #0
	std 8,x
	.dbline 112
;      /* Set negative direction of motors */
;   	if (index == RIGHT_MOTOR) CLEAR_BIT(PORTD,0x20); /*Right motor*/
	ldd 4,x
	bne L8
	ldy #0x1008
	bclr 0,y,#0x20
L8:
	.dbline 113
;         if (index == LEFT_MOTOR) CLEAR_BIT(PORTD,0x10); /*Left motor*/
	ldd 4,x
	cpd #1
	bne L7
	ldy #0x1008
	bclr 0,y,#0x10
	.dbline 114
;      }
	bra L7
L6:
	.dbline 118
;   else
;      {
;      /* Set positive direction of motors */
;         if (index == RIGHT_MOTOR) SET_BIT(PORTD, 0x20); /*Right motor*/
	ldd 4,x
	bne L12
	ldy #0x1008
	bset 0,y,#32
L12:
	.dbline 119
;         if (index == LEFT_MOTOR) SET_BIT(PORTD, 0x10); /*Left motor*/
	ldd 4,x
	cpd #1
	bne L14
	ldy #0x1008
	bset 0,y,#16
L14:
	.dbline 120
;      }
L7:
	.dbline 125
; 
; /* At this point per_cent_duty_cycle must be a positive number less
;  * than 100. If not make it so.
;  */
;   if (per_cent_duty_cycle > 100) per_cent_duty_cycle = 100;
	ldd 8,x
	cpd #100
	ble L16
	ldd #100
	std 8,x
L16:
	.dbline 126
;   duty_cycle[index] = per_cent_duty_cycle*PERIOD_1PC;
	ldd #655
	ldy 8,x
	jsr __muli
	pshb ; 
	psha ; spill
	ldd 4,x
	lsld
	addd #_duty_cycle
	xgdy
	pula ; 
	pulb ; reload
	std 0,y
	.dbline 128
; 
; }
L5:
	inx
	inx
	txs
	pulx
	puly
	rts
;  IX -> 0,x
;  rMEM -> 2,x
;          index -> 4,x
;            odd -> 5,x
;         pwidth -> 6,x
_motorme_hand::
	jsr __enterb
	.byte 0x8
	.dbfunc motorme_hand
	.dbline 162
; /*********************** End motor ***********************************/
; 
; 
; 
; 
; void motorme_hand(void)
; /************************************************************************
;  * Function: Interrupt handler for motor signals                        *
;  * Returns: None                                                        *
;  *                                                                      *
;  * Inputs                                                               *
;  *   Parameters: None                                                   *
;  *   Globals:    duty_cycle[], signal_state, motormask[], current_duty_cycle      *
;  *   Registers:  None                                                   *
;  * Outputs                                                              *
;  *   Parameters: None                                                   *
;  *   Globals:    current_duty_cycle                                          *
;  *   Registers:  TOC5, PORTA, TFLG1      				                *
;  * Functions called: None                                               *
;  * Notes: None                                                          *
;  ************************************************************************/
; {
;   char odd, index;
;   unsigned int pwidth;
; 
; /*
;  Control is passed alternately between the motors each half period
;    signal_state = 0  -> Turn on motor0
;    signal_state = 1  -> Turn off motor0
;    signal_state = 2  -> Turn on motor1
;    signal_state = 3  -> Turn off motor1
; */
; 
;   signal_state &= 0x03;         /* Only use last 2 bits */
	ldy #_signal_state
	bclr 0,y,#0xfc
	.dbline 163
;   index = (signal_state >> 1);  /* index references current motor */
	ldab _signal_state
	clra
	tstb
	bpl X0
	coma
X0:
	asra
	rorb
	stab 4,x
	.dbline 165
; 
;   odd = (signal_state & 0x01);
	ldab _signal_state
	andb #1
	stab 5,x
	.dbline 167
; 
;   pwidth = duty_cycle[index]; /*Load the duty_cycle into pwidth*/
	ldab 4,x
	clra
	tstb
	bpl X1
	coma
X1:
	lsld
	addd #_duty_cycle
	xgdy
	ldd 0,y
	std 6,x
	.dbline 169
;   
;   if ((pwidth == 0)&&(!(odd)))
	ldd 6,x
	bne L19
	tst 5,x
	bne L19
	.dbline 171
;   {
;     TOC5 += HALFPERIOD;
	; vol
	ldd 0x101e
	addd #32
	std 0x101e
	.dbline 172
;     signal_state++;
	inc _signal_state
	.dbline 173
;   }
	bra L20
L19:
	.dbline 176
;   else
;   {
;     if (odd)
	tst 5,x
	beq L21
	.dbline 177
;       TOC5 += (HALFPERIOD - current_duty_cycle);
	ldd #750
	subd _current_duty_cycle
	std 2,x
	; vol
	ldd 0x101e
	addd 2,x
	std 0x101e
	bra L22
L21:
	.dbline 179
;     else
;       TOC5 += pwidth;
	; vol
	ldd 0x101e
	addd 6,x
	std 0x101e
L22:
	.dbline 182
; 
;   /* Right motor signal goes on PA5, and left motor signal goes on PA6*/
;     PORTA ^= motormask[index];
	ldab 4,x
	clra
	tstb
	bpl X2
	coma
X2:
	addd #_motormask
	xgdy
	; vol
	ldab 0x1000
	eorb 0,y
	stab 0x1000
	.dbline 183
;   }
L20:
	.dbline 185
; 
;   current_duty_cycle = pwidth;
	ldd 6,x
	std _current_duty_cycle
	.dbline 187
;   
;   signal_state++;
	inc _signal_state
	.dbline 189
;   
;   if (signal_state == 4) signal_state = 0;
	ldab _signal_state
	cmpb #4
	bne L23
	clr _signal_state
L23:
	.dbline 191
;    
;   CLEAR_FLAG(TFLG1,0x08);          /* Clear OC5I flag */
	ldy #0x1023
	bclr 0,y,#0xf7
	.dbline 193
; 
; }/*end of motorme_hand*/
L18:
	xgdx
	addd #8
	xgdx
	txs
	pulx
	rts
	.area bss
_motormask::
	.blkb 2
_signal_state::
	.blkb 1
_current_duty_cycle::
	.blkb 2
_duty_cycle::
	.blkb 4
