	.module motormex.c
	.dbfile motormex.c
	.area text
;  IX -> 0,x
_init_motorme::
			sei

	.dbfile motormex.c
	.dbfunc init_motorme
	.dbline 77
; /**********************************************************************
;  * 			MEKATRONIX Copyright 1998 		      *
;  * Title        motorme.c  (Motor Drivers for ME11)                *
;  * Programmer   Keith L. Doty                      *
;  * Date         May 09, 1999                                        *
;  * 				                                                     *
;  * Version      1  
;      Changed some names, set PACTL bits with one command, cleaned up.
;  *                                                                    *
;  * Description                                                        *
;  * Left motor is motor 1 (PA6) and right motor is motor 0 (PA5).      *
;  * For efficient use of output compares, OC5 is used to modulate pins *
;  * both PA5 and PA6. 		      *
;  **********************************************************************/
; 
; 
; /**************************** Includes **********************************/
; #include <hc11.h>
; #include <mil.h>
; /************************************************************************/
; 
; 
; /**************************** Constants *********************************/
; /*Full period for a motor in clock cycles. A clock cycle is 0.5 microseconds*/
; #define MOTOR_HPERIOD 20000
; 
; /* One percent of full motor period in clock cycles*/
; #define PERIOD_1PC 400   
; 
; #define LEFT_MOTOR 1
; #define RIGHT_MOTOR 0
; 
; #define PA5_PA6_ONE 0x60
; #define PA5_ONE 0x20
; #define PA6_ONE 0x40
; 
; #define motorme_hand   TOC5_isr
; /************************************************************************/
; 
; 
; /*************************** Prototypes *********************************/
; #pragma interrupt_handler TOC5_isr
; void init_motorme(void);
; void motorme(int, int);
; void motorme_hand(void);
; /************************************************************************/
; 
; 
; /***************************** Globals **********************************/
; unsigned int duty_cycle[2];       /* duty_cycle[] is the on-time for each motor*/
; unsigned int current_duty_cycle;
; char signal_state, motormask[2];
; unsigned int period_end, delta0, delta1;
; /************************************************************************/
; 
; 
; 
; void init_motorme(void)
; /************************************************************************
;  * Function: Initializes all necessary variables for the motors.        *
;  * Returns: None                                                        *
;  *                                                                      *
;  * Inputs                                                               *
;  *   Parameters: None                                                   *
;  *   Globals:    None                                                   *
;  *   Registers:  None                                                   *
;  * Outputs                                                              *
;  *   Parameters: None                                                   *
;  *   Globals:   duty_cycle[], signal_state, motormask[], current_duty_cycle       *
;  *   Registers: TOC5, TMSK1, TCTL1                               *
;  * Functions called: None                                               *
;  * Notes: None                                                          *
;  ************************************************************************/
; {
; 
;   INTR_OFF();
;   CLEAR_BIT(TCTL1,0x03);          /* Interrupt will not affect OC5 pin */
	ldy #0x1020
	bclr 0,y,#0x3
	.dbline 79
; 
;   TOC5 = 0;                       
	ldd #0
	std 0x101e
	.dbline 80
;   PORTA = 0;
	clr 0x1000
	.dbline 82
; 
;   duty_cycle[0] = duty_cycle[1] =  0;      /* Motors start turned off */
	ldd #0
	std _duty_cycle+2
	ldd #0
	std _duty_cycle
	.dbline 83
;   signal_state = 0;
	clr _signal_state
	.dbline 84
;   current_duty_cycle = 0;
	ldd #0
	std _current_duty_cycle
	.dbline 85
;   motormask[0] = 0x20;		/* Drives PA5, right motor*/
	ldab #32
	stab _motormask
	.dbline 86
;   motormask[1] = 0x40;		/* Drives PA6, left motor*/
	ldab #64
	stab _motormask+1
	.dbline 88
; 
;   SET_BIT(TMSK1,0x08);            /* Enable OC5 interrupt */
	ldy #0x1022
	bset 0,y,#8
			cli

	.dbline 90
;   INTR_ON();
; }/*end init_motorme*/
L2:
	rts
;  IX -> 0,x
; per_cent_duty_cycle -> 8,x
;          index -> 4,x
_motorme::
	pshb
	psha
	pshx
	pshx
	tsx
	stx 0,x
	.dbfunc motorme
	.dbline 114
; 
; 
; void motorme(int index, int per_cent_duty_cycle)
; /************************************************************************
;  * Function description:						*
;  *   Sets duty cycle and direction of motor specified by index.	    	*
;  *				                                        *
;  * Returns:                                                           	*
;  *                                                                    	*
;  * Inputs                                                             	*
;  *   Parameters: index: 0 = left motor, 1 = right motor               	*
;  *		     -100 <= per_cent_duty_cycle<= 100%		        *
;  *   Globals:    None                                                 	*
;  *   Registers:  None                                                 	*
;  * Outputs                                                            	*
;  *   Parameters: None                                                 	*
;  *   Globals:    duty_cycle[index]					*
;         0 <= duty_cycle[index]<= PERIOD (Typically, PERIOD = 65,500)  	*
;  *   Registers:  None                                                 	*
;  * Functions called: None                                             	*
;  * Notes: Checks for proper input bounds. 			 	*
;  ************************************************************************/
; {
;   if (per_cent_duty_cycle < 0)
	ldd 8,x
	bge L6
	.dbline 116
;      {
;         per_cent_duty_cycle = -per_cent_duty_cycle; /* Make positive */
	ldd 8,x
	nega
	negb
	sbca #0
	std 8,x
	.dbline 118
;      /* Set negative direction of motors */
;   	if (index == RIGHT_MOTOR) CLEAR_BIT(PORTD,0x20); /*Right motor*/
	ldd 4,x
	bne L8
	ldy #0x1008
	bclr 0,y,#0x20
L8:
	.dbline 119
;         if (index == LEFT_MOTOR) CLEAR_BIT(PORTD,0x10); /*Left motor*/
	ldd 4,x
	cpd #1
	bne L7
	ldy #0x1008
	bclr 0,y,#0x10
	.dbline 120
;      }
	bra L7
L6:
	.dbline 124
;   else
;      {
;      /* Set positive direction of motors */
;         if (index == RIGHT_MOTOR) SET_BIT(PORTD, 0x20); /*Right motor*/
	ldd 4,x
	bne L12
	ldy #0x1008
	bset 0,y,#32
L12:
	.dbline 125
;         if (index == LEFT_MOTOR) SET_BIT(PORTD, 0x10); /*Left motor*/
	ldd 4,x
	cpd #1
	bne L14
	ldy #0x1008
	bset 0,y,#16
L14:
	.dbline 126
;      }
L7:
	.dbline 131
; 
; /* At this point per_cent_duty_cycle must be a positive number less
;  * than 100. If not make it so.
;  */
;   if (per_cent_duty_cycle > 100) per_cent_duty_cycle = 100;
	ldd 8,x
	cpd #100
	ble L16
	ldd #100
	std 8,x
L16:
	.dbline 132
;   duty_cycle[index] = per_cent_duty_cycle*PERIOD_1PC;
	ldd #400
	ldy 8,x
	jsr __muli
	pshb ; 
	psha ; spill
	ldd 4,x
	lsld
	addd #_duty_cycle
	xgdy
	pula ; 
	pulb ; reload
	std 0,y
	.dbline 134
; 
; }
L5:
	inx
	inx
	txs
	pulx
	puly
	rts
L34:
	.word L22
	.word L29
	.word L30
	.word L31
	.word L32
	.word L33
;  IX -> 0,x
;          ?temp -> 2,x
;          index -> 4,x
;            odd -> 5,x
;        pwidth1 -> 6,x
;        pwidth0 -> 8,x
_TOC5_isr::
	jsr __enterb
	.byte 0xa
	.dbfunc TOC5_isr
	.dbline 173
; /*********************** End motor ***********************************/
; 
; 
; 
; 
; void motorme_hand(void)
; //Assumption: Pulse Width in multiples of 400 (1 percent duty cycle)
; /************************************************************************
;  * Function: Interrupt handler for motor signals                        *
;  * Returns: None                                                        *
;  *                                                                      *
;  * Inputs                                                               *
;  *   Parameters: None                                                   *
;  *   Globals:    duty_cycle[], signal_state, motormask[], current_duty_cycle      *
;  *   Registers:  None                                                   *
;  * Outputs                                                              *
;  *   Parameters: None                                                   *
;  *   Globals:    current_duty_cycle                                          *
;  *   Registers:  TOC5, PORTA, TFLG1      				                *
;  * Functions called: None                                               *
;  * Notes: None                                                          *
;  ************************************************************************/
; {
;   char odd, index;
;   unsigned int pwidth0, pwidth1;
;   
;   /*
;  Control is passed alternately between the motors each half period
;    signal_state = 0  -> Turn on  PA5 (motor0) and PA6 (motor1)
;    signal_state = 1  -> Turn off PA5 continue PA6
;    signal_state = 2  -> Turn off PA6 continue PA5
;    signal_state = 3  -> Turn off PA6 and time out rest of period
;    signal_state = 4  -> Turn off PA5 and time out rest of period
;    signal_state = 5  -> Turn off both pulses and time out rest of period
; 
;    signal_state Sequences: 0-5-0, 0-1-3-0, 0-2-4-0
; */
; 
;   switch(signal_state)
	ldab _signal_state
	clra
	tstb
	bpl X0
	coma
X0:
	std 2,x
	bge X1
	jmp L19
X1:
	ldd 2,x
	cpd #5
	ble X2
	jmp L19
X2:
	ldd 2,x
	lsld
	addd #L34
	xgdy
	ldy 0,y
	jmp 0,y
L22:
	.dbline 177
;   {
;   case 0:
;   
;     pwidth0 = duty_cycle[1];
	ldd _duty_cycle+2
	std 8,x
	.dbline 178
;     pwidth1 = duty_cycle[2];
	ldd _duty_cycle+4
	std 6,x
	.dbline 179
;     period_end = TOC5 + MOTOR_HPERIOD + MOTOR_HPERIOD;
	; vol
	ldd 0x101e
	addd #20000
	addd #20000
	std _period_end
	.dbline 181
;     
;     if(pwidth0 < pwidth1)
	ldd 8,x
	cpd 6,x
	bhs L25
	.dbline 183
;     {
;       TOC5 += pwidth0;			//PA5 shorter
	; vol
	ldd 0x101e
	addd 8,x
	std 0x101e
	.dbline 184
;       delta1 = pwidth1-pwidth0;
	ldd 6,x
	subd 8,x
	std _delta1
	.dbline 185
;       signal_state = 1;
	ldab #1
	stab _signal_state
	.dbline 186
;     }
	bra L26
L25:
	.dbline 188
;     else
;       if(pwidth1 < pwidth0)
	ldd 6,x
	cpd 8,x
	bhs L27
	.dbline 190
;       {
;         TOC5 += pwidth1;		//PA6 shorter
	; vol
	ldd 0x101e
	addd 6,x
	std 0x101e
	.dbline 191
;         delta0 = pwidth0-pwidth1;
	ldd 8,x
	subd 6,x
	std _delta0
	.dbline 192
;         signal_state = 2;
	ldab #2
	stab _signal_state
	.dbline 193
;       }
	bra L28
L27:
	.dbline 195
;       else
;         signal_state = 5;
	ldab #5
	stab _signal_state
L28:
L26:
	.dbline 197
;       
;     PORTA ^= PA5_PA6_ONE;	//Turn both motor pulses on
	; vol
	ldab 0x1000
	eorb #96
	stab 0x1000
	.dbline 199
;     
;   break; //End of signal_state = 0
	bra L20
L29:
	.dbline 203
;   
;   case 1:
;    
;     PORTA ^= PA5_ONE;	//Turn PA5 off and leave PA6 on
	; vol
	ldab 0x1000
	eorb #32
	stab 0x1000
	.dbline 204
;     TOC5 += delta1;
	; vol
	ldd 0x101e
	addd _delta1
	std 0x101e
	.dbline 205
;     signal_state = 3;
	ldab #3
	stab _signal_state
	.dbline 207
;     
;   break; //End of signal_state = 1
	bra L20
L30:
	.dbline 211
;   
;   case 2: 
;         
;     PORTA ^= PA6_ONE;	//Turn PA6 off and leave PA5 on
	; vol
	ldab 0x1000
	eorb #64
	stab 0x1000
	.dbline 212
;     TOC5 += delta0;
	; vol
	ldd 0x101e
	addd _delta0
	std 0x101e
	.dbline 213
;     signal_state = 4;
	ldab #4
	stab _signal_state
	.dbline 215
;     
;   break; //End of signal_state = 2
	bra L20
L31:
	.dbline 219
; 
;   case 3: 
;       
;     PORTA ^= PA6_ONE;	//Turn PA6 off and time out period
	; vol
	ldab 0x1000
	eorb #64
	stab 0x1000
	.dbline 220
;     TOC5 = period_end;
	ldd _period_end
	std 0x101e
	.dbline 221
;     signal_state = 0;
	clr _signal_state
	.dbline 223
;     
;   break; //End of signal_state = 3
	bra L20
L32:
	.dbline 227
;     
;   case 4: 
;       
;     PORTA ^= PA5_ONE;	//Turn PA5 off and time out period
	; vol
	ldab 0x1000
	eorb #32
	stab 0x1000
	.dbline 228
;     TOC5 += period_end;
	; vol
	ldd 0x101e
	addd _period_end
	std 0x101e
	.dbline 229
;     signal_state = 0;
	clr _signal_state
	.dbline 231
;     
;   break; //End of signal_state = 4
	bra L20
L33:
	.dbline 235
;   
;   case 5:
;       
;     PORTA ^= PA5_PA6_ONE;	//Turn PA5 and PA6 off and time out period
	; vol
	ldab 0x1000
	eorb #96
	stab 0x1000
	.dbline 236
;     TOC5 += period_end;
	; vol
	ldd 0x101e
	addd _period_end
	std 0x101e
	.dbline 237
;     signal_state = 0;
	clr _signal_state
	.dbline 239
;     
;   break; //End of signal_state = 5
L19:
L20:
	.dbline 242
;   }
;        
;   CLEAR_FLAG(TFLG1,0x08);          /* Clear OC5I flag */
	ldy #0x1023
	bclr 0,y,#0xf7
	.dbline 244
; 
; }/*end of motorme_hand*/
L18:
	xgdx
	addd #10
	xgdx
	txs
	pulx
	rti
	.area bss
_delta1::
	.blkb 2
_delta0::
	.blkb 2
_period_end::
	.blkb 2
_motormask::
	.blkb 2
_signal_state::
	.blkb 1
_current_duty_cycle::
	.blkb 2
_duty_cycle::
	.blkb 4
