/************************************************************************
 * 			MEKATRONIX Copyright 1998 			*
 * Title        xsv2tjp.c                                                *
 * Programmer	Keith L. Doty	        				*
 * Date         Sept 04, 1998                                           *
 * Version	1			                		*
 *								        *
 * Description								*
 *   Set the position of Servo_0, Servo1 and Servo2.			*
 *                                       				*     					*
 *   A physical, serial communication link must be present, e.g. the    *
 *   standard Mekatronix serial cable connection via the MB2325 board.	*
 *									*
 * Use Hyperterm with the following settings:      			*
 *      COM1, 9600 Baud, 8 bits, No Parity, 1 Stop bit, No Flow         *
 *      of Control, VT100 Terminal, WrapLines.				*
 *                                       				*     					*
 ************************************************************************/
 
/**************************** Includes **********************************/
#include <tjpbase.h>
/************************ End of includes *******************************/

void main(void)
/****************************** Main ***********************************/
{
  int servoz_pos, servo1_pos, servo2_pos;

/* VT100 clear screen */ 
  char clear[]= "\x1b\x5B\x32\x4A\x04"; 

/* VT100 position cursor at (x,y) = (3,12) command is "\x1b[3;12H"*/
  char place[]= "\x1b[1;1H";	/*Home*/	

  init_analog();
  init_clocktjp();
  init_serial();
  init_servotjp();
  init_clocktjp();
  
  printf("%s", clear);  
  printf("%s", place);
 
  printf("\tTitle\t\txsv2tjp.c\n"
  "\tProgrammer\tKeith L. Doty\n"
  "\tDate\t\tSept. 15, 1998\n"
  "\tVersion\t\t1\n\n");
printf(" Description\n"
 "   Input three integers to specify the position of three servos.\n"
 "   The integer ranges are highly variable between servos. You will\n"
 "   need to explore values. Usually, anything below 1000 is too small\n"
 "   and above 5100 too large. At extreme values you may overdrive the\n"
 "   the servos, indicated by continued pulsing of the motors to\n"
 "   position the servo. Do not overdrive servos too long!\n\n" 
 "   To input another set of servo positions press reset to start\n"
 "   the program over.\n\n"
 "   Mechanical Calibration of the Servo\n"
 "     Mount servo horn, rotate counterclockwise until it comes against\n"
 "     a hard stop. Remount the servo horn so that two of its arms are\n"
 "     as nearly perpendicular to the sides of the servo case as possible.\n"
 "     The teeth on the output shaft will leave you a choice of two mounting\n"
 "     postions. Pick the positon that requires back rotation to make the arms\n"
 "     of the servo horn perpendicular to the case sides. This position will\n"
 "     define the zero angle (180 degrees in some servos).\n\n"
 "  Usage:\n"
 "    This program allows you to set the robot servos at any fixed position.\n\n");


  printf("Enter Servo_0 position:   ");
  servoz_pos= read_int();
 
  printf("Enter Servo_1 position:  ");
  servo1_pos = read_int();

  printf("Enter Servo2 position:  ");
  servo2_pos = read_int();

  servo(0, servoz_pos);
  servo(1, servo1_pos);
  servo(2, servo2_pos);
}
/**************************** End of Main ******************************/
